@@ -16,3 +16,5 @@ from .LunarYear import LunarYear
 from .LunarMonth import LunarMonth
 from .LunarTime import LunarTime
 from .Holiday import Holiday
+from .Foto import Foto
+from .FotoFestival import FotoFestival
